Shared app-wide UI asset bundles.
Keep CSS/JS asset ordering centralized here so modules can reuse the same rendering contract without hardcoding per-page lists.
Shared app-wide UI asset bundles. Keep CSS/JS asset ordering centralized here so modules can reuse the same rendering contract without hardcoding per-page lists.
Admin pilot stack with legacy admin rules plus daisy overrides.
Admin pilot stack with legacy admin rules plus daisy overrides.
Admin pilot JavaScript stack. components.js and admin-ux.js must load before alpine.min.js because they register Alpine components/stores via the alpine:init event.
Admin pilot JavaScript stack. components.js and admin-ux.js must load before alpine.min.js because they register Alpine components/stores via the alpine:init event.
Base JavaScript stack. components.js must load before alpine.min.js to register shared Alpine components.
Base JavaScript stack. components.js must load before alpine.min.js to register shared Alpine components.
(bundle k)Return stylesheet list for k bundle key.
Falls back to :base.
Return stylesheet list for `k` bundle key. Falls back to `:base`.
Registry of known stylesheet bundles.
Registry of known stylesheet bundles.
(js-bundle k)Return JavaScript list for k bundle key.
Falls back to :base.
Return JavaScript list for `k` bundle key. Falls back to `:base`.
Registry of known JavaScript bundles.
Registry of known JavaScript bundles.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |