boundary.ui-style

Shared app-wide UI asset bundles.

Keep CSS/JS asset ordering centralized here so modules can reuse the same rendering contract without hardcoding per-page lists.

Shared app-wide UI asset bundles.

Keep CSS/JS asset ordering centralized here so modules can reuse the same
rendering contract without hardcoding per-page lists.
raw docstring

admin-pilot-cssclj

Admin pilot stack with legacy admin rules plus daisy overrides.

Admin pilot stack with legacy admin rules plus daisy overrides.
sourceraw docstring

admin-pilot-jsclj

Admin pilot JavaScript stack.

Admin pilot JavaScript stack.
sourceraw docstring

base-cssclj

Legacy-compatible base stack.

Legacy-compatible base stack.
sourceraw docstring

base-jsclj

Base JavaScript stack. Alpine.js must load before HTMX.

Base JavaScript stack.
Alpine.js must load before HTMX.
sourceraw docstring

bundleclj

(bundle k)

Return stylesheet list for k bundle key. Falls back to :base.

Return stylesheet list for `k` bundle key.
Falls back to `:base`.
sourceraw docstring

css-bundlesclj

Registry of known stylesheet bundles.

Registry of known stylesheet bundles.
sourceraw docstring

js-bundleclj

(js-bundle k)

Return JavaScript list for k bundle key. Falls back to :base.

Return JavaScript list for `k` bundle key.
Falls back to `:base`.
sourceraw docstring

js-bundlesclj

Registry of known JavaScript bundles.

Registry of known JavaScript bundles.
sourceraw docstring

pilot-cssclj

General daisy pilot stack.

General daisy pilot stack.
sourceraw docstring

pilot-jsclj

Pilot JavaScript stack.

Pilot JavaScript stack.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries